@@ -1,5 +1,5 @@
 solution <- function(graph, weight, solved_to_optimality = FALSE, ...) {
-    stopifnot(igraph::is_connected(graph))
+    stopifnot((igraph::vcount(graph) == 0) || igraph::is_connected(graph))
     obj <- c(list(graph = graph, weight = weight,
                   solved_to_optimality = solved_to_optimality), list(...))
     structure(obj, class = "mwcsp_solution")
